/***************************************************************************
 *   Copyright (C) 2004 by EVER Sp. z o.o.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PS_DRV_SINLINEXL_H
#define PS_DRV_SINLINEXL_H

#include "ioctldef.h"
#include "structs.h"
//#include "ps_drv_sinline_upsdefs.h"

/* 
 * Driver definitions
 */
#define DRIVER_VERSION_MAJOR			0
#define DRIVER_VERSION_MINOR			9
#define DRIVER_VERSION_SUBMINOR			1

#define DRIVER_CONFIG_FILE				"sinlinexl.conf"
#define DRIVER_UPS_FAMILY				"SINLINE 700-3000"
#define DRIVER_UPS_PREFIX				"SINLINE"

#define UPS_MAX_MODELS					6

#define UPS_MODEL700						"700"
#define UPS_MODEL1000					"1000"
#define UPS_MODEL1500					"1500"
#define UPS_MODEL2000					"2000"
#define UPS_MODEL2500					"2500"
#define UPS_MODEL3000					"3000"

/* 
 * Licznik pozycji ustawie z drivera
 */
#define INT_MAX_SETUPITEMS				11
/* 
 * Identyfikatory ustawie UPS-a
 */
#define INT_UPSCFG_SERIALCOMM			0
#define INT_UPSCFG_BUZZER				1
#define INT_UPSCFG_OUTPUTFREQ			2
#define INT_UPSCFG_SENSITIVITY			3
#define INT_UPSCFG_V_DOLNY				4
#define INT_UPSCFG_V_GORNY				5
#define INT_UPSCFG_V_DOLNY_AVR			6
#define INT_UPSCFG_V_GORNY_AVR			7
#define INT_UPSCFG_STANDBYDELAY			8
#define INT_UPSCFG_UPSSHUTDOWN			9
#define INT_UPSCFG_LOWBATTERYTRSH		10

/* 
 * Kody zawartoci ramek transmisyjnych
 */
#define FRAME_INITCODE					0xD0
#define FRAME_START						0x1F
#define FRAME_CMD_GET					0x0F
#define FRAME_CMD_SET					0xF0
#define FRAME_CMD_SPECIAL				0xFF

/* 
 * Flagi dla KONTROLA_PRACY
 */
#define FLAG_KONTROLA_PRACY_BUZZER		0x40
#define FLAG_KONTROLA_PRACY_SHUTDOWN	0x10
#define FLAG_KONTROLA_PRACY_STANDBY		0x08

/* 
 * Macros
 */
#undef FAILED
#define FAILED( var )				(bool)((var == 0) ? 0 : 1)

#undef COMMFAIL
#define COMMFAIL( var )				(bool)((var == 1) ? 0 : 1)

 /* 
 * Structures
 */
typedef struct _sdrv_config_
{
	/* struct size used for versioning */
	unsigned long	ulSize;
	/* serial port configured by user */
	char			szSerialPort[16];
	/* flag used to determine if driver is running */
	bool			bDrvActive;
	/* flag used to determine if external program has updated this file to setup */
	bool			bDrvToUpdate;
	/* variable used to keep setting about percent of battery capacity at which 
	 * low battery is signalled */
	unsigned int	uiBattCapToLB;
	/* UPS tables */
/*	int	iCharacterTable[ UPS_CHARAKTER_COUNT ];
	int	iHardwareTable[ UPS_SPRZET_COUNT ];
	int	iInfTable[ UPS_INF_COUNT ];
	int	iSetupTable[ UPS_SETUP_COUNT ];
	int	iSpecialTable[ UPS_SPECIAL_COUNT ];
*/
} sdrv_config, *lpsdrv_config;

/* 
 * Enumerators
 */
typedef enum _eups_structs_
{
	EU_INFORMATIONS		= 1,
	EU_SETUP			= 2,
	EU_SPECIAL			= 3,
	EU_HARDWARE			= 4,
	EU_CHARACTERISTIC	= 5
} eups_structs;

/* 
 * Function prototypes - internal
 */
int sinlinexl_ioctl(long lCommand, void *lpvBuff, int *lpibuffsize);

int	DoInit(void *lpvBuff, int *lpiBuffSize);
int	DoUnInit(void *lpvBuff, int *lpiBuffSize);
int	DoAutoConfigure(void *lpvBuff, int *lpiBuffSize);
int	DoConfigure(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsInfoMask(void *lpvBuff, int *lpiBuffSize);
int	DoSetUpsInfoMask(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsStateMask(void *lpvBuff, int *lpiBuffSize);
int	DoSetUpsStateMask(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsState(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsParamsMask(void *lpvBuff, int *lpiBuffSize);
int	DoSetUpsParamsMask(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsParams(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsSetupParamsMask(void *lpvBuff, int *lpiBuffSize);
int	DoSetUpsSetupParamsMask(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsSetupParams(void *lpvBuff, int *lpiBuffSize);
int	DoSetUpsSetupParams(void *lpvBuff, int *lpiBuffSize);
int	DoGetDriverInfo(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsCharacteristics(void *lpvBuff, int *lpiBuffSize);
int	DoGetExtendedError(void *lpvBuff, int *lpiBuffSize);
int	DoTestUpsLink(void *lpvBuff, int *lpiBuffSize);
int	DoGetUPSStructures(eups_structs eType, void *lpvBuff, int *lpiBuffSize);
int	DoSetUPSStructures(eups_structs eType, void *lpvBuff, int *lpiBuffSize, int *lpiBuffErrPos);
int	DoGetUpsCharacteristicMask(void *lpvBuff, int *lpiBuffSize);
int	DoGetUpsCharacteristic(void *lpvBuff, int *lpiBuffSize);
int	DoGetConfigParamsCount(void *lpvBuff, int *lpiBuffSize);
int	DoGetConfigParams(void *lpvBuff, int *lpiBuffSize);
int	DoGetConfigParam(void *lpvBuff, int *lpiBuffSize);
int	DoSetConfigParams(void *lpvBuff, int *lpiBuffSize);
int	DoSetConfigParam(void *lpvBuff, int *lpiBuffSize);
int	DoUpdateConfig(void *lpvBuff, int *lpiBuffSize);
int	DoGetDriverMode(void *lpvBuff, int *lpiBuffSize);
int	DoUpsShutdown(void *lpvBuff, int *lpiBuffSize);
int	CheckForUPSConfigUpdate();



#endif/*PS_DRV_SINLINEXL_H*/

