/***************************************************************************
 *   Copyright (C) 2004 by EVER Sp. z o.o.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SINLINEXL_H
#define SINLINEXL_H

#include "structs.h"
#include "gldefs.h"
#include "ioctldef.h"

#ifdef SINLINEXL_DRIVER_BUILD

/* 
 * Driver definitions
 */
#define DRIVER_VERSION_MAJOR			0
#define DRIVER_VERSION_MINOR			0
#define DRIVER_VERSION_SUBMINOR		1

#define DRIVER_BITMAP_FILE				PIX_PATH"/sinlinexl.bmp"
#define DRIVER_CONFIG_FILE				"sinlinexl.conf"
#define DRIVER_UPS_FAMILY				"SINLINE XL 700-3000"
#define DRIVER_UPS_PREFIX				"SINLINE XL"

#define UPS_MAX_MODELS					6
#define UPS_MODEL_700					"700"
#define UPS_MODEL_1000					"1000"
#define UPS_MODEL_1500					"1500"
#define UPS_MODEL_2000					"2000"
#define UPS_MODEL_2500					"2500"
#define UPS_MODEL_3000					"3000"

/* identyfikatory typow */
#define UPS_SINLINE_700					1
#define UPS_SINLINE_1000				2
#define UPS_SINLINE_1500				3
#define UPS_SINLINE_2000				4
#define UPS_SINLINE_2500				5
#define UPS_SINLINE_3000				6

/* 
 * Licznik pozycji ustawie z drivera
 */
#define INT_MAX_SETUPITEMS				11
/* 
 * Identyfikatory ustawie UPS-a
 */
#define INT_UPSCFG_SERIALCOMM			0
#define INT_UPSCFG_BUZZER				1
#define INT_UPSCFG_OUTPUTFREQ			2
#define INT_UPSCFG_SENSITIVITY		3
#define INT_UPSCFG_V_DOLNY				4
#define INT_UPSCFG_V_GORNY				5
#define INT_UPSCFG_V_DOLNY_AVR		6
#define INT_UPSCFG_V_GORNY_AVR		7
#define INT_UPSCFG_STANDBYDELAY		8
#define INT_UPSCFG_UPSSHUTDOWN		9
#define INT_UPSCFG_LOWBATTERYTRSH	10

////////////////////////////////////////////////////////
////////////////////////////////////////////////////////
/* 
 * definicje tablic - sprzetowe
 */
#include "sinlinexl_ups.h"
////////////////////////////////////////////////////////
////////////////////////////////////////////////////////


/* 
 * Kody zawartosci ramek transmisyjnych
 */
#define FRAME_INITCODE					0xD0
#define FRAME_BUSY						0xCF
#define FRAME_START						0x1F
#define FRAME_CMD_GET					0x0F
#define FRAME_CMD_SET					0xF0
#define FRAME_CMD_SPECIAL				0xFF

/* 
 * Flagi dla KONTROLA_PRACY
 */
#define FLAG_KONTROLA_PRACY_BUZZER		0x40
#define FLAG_KONTROLA_PRACY_SHUTDOWN	0x10
#define FLAG_KONTROLA_PRACY_STANDBY		0x08

/*
 * Structures
 */
typedef struct _sdrv_config_
{
	/* struct size used for versioning */
	unsigned long	ulSize;
	/* serial port configured by user */
	int				iSerialPort;
	char			szSerialPort[MAX_PATHBUFF];
	/* a variable used to keep setting about percent of battery capacity at which 
	 * low battery is signalled */
	unsigned int	uiBattCapToLB;
	/* UPS tables */
	unsigned int	uiCharacterTable[ UPS_CHARAKTER_COUNT ];
	unsigned int	uiHardwareTable[ UPS_SPRZET_COUNT ];
	unsigned int	uiInfTable[ UPS_INF_COUNT ];
	unsigned int	uiSetupTable[ UPS_SETUP_COUNT ];
	unsigned int	uiSpecialTable[ UPS_SPECIAL_COUNT ];

} sdrv_config, *lpsdrv_config;

/* 
 * Enumerators
 */
typedef enum _eups_structs_
{
	EU_INFORMATIONS	= 1,
	EU_SETUP				= 2,
	EU_SPECIAL			= 3,
	EU_HARDWARE			= 4,
	EU_CHARACTERISTIC	= 5
} eups_structs;

/* 
 * Function prototypes - internal
 */
int		SinlineXL_DoInit(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoUnInit(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetConfigFileName(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoAutoConfigure(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoConfigure(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsInfoMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUpsInfoMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsStateMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUpsStateMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsState(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsParamsMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUpsParamsMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsParams(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsSetupParamsMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUpsSetupParamsMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsSetupParams(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUpsSetupParams(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetDriverInfo(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsCharacteristics(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetExtendedError(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoTestUpsLink(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUPSStructures(eups_structs eType, void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetUPSStructures(eups_structs eType, void *lpvBuff, int *lpiBuffSize, int *lpiBuffErrPos);
int		SinlineXL_DoGetUpsCharacteristicMask(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetUpsCharacteristic(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetConfigParamsCount(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetConfigParams(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetConfigParam(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetConfigParams(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoSetConfigParam(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoUpdateConfig(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoGetDriverMode(void *lpvBuff, int *lpiBuffSize);
int		SinlineXL_DoUpsShutdown(void *lpvBuff, int *lpiBuffSize);

int		SinlineXL_ReadConfig();

#else /*SINLINEXL_DRIVER_BUILD*/

int		sinlinexl_ioctl(long lCommand, void *lpvBuff, int *lpiBuffSize);

#endif/*SINLINEXL_DRIVER_BUILD*/

#endif/*SINLINEXL_H*/
